/*
 * Ibis - IRCv3 Library
 * Copyright (C) 2022-2024 Ibis Developers
 *
 * Ibis is the legal property of its developers, whose names are too numerous
 * to list here.  Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#include "ibisversion.h"

/******************************************************************************
 * Externals
 *****************************************************************************/
const guint ibis_major_version = IBIS_MAJOR_VERSION;
const guint ibis_minor_version = IBIS_MINOR_VERSION;
const guint ibis_micro_version = IBIS_MICRO_VERSION;
const char *ibis_version = IBIS_VERSION;

/******************************************************************************
 * Public API
 *****************************************************************************/
const char *
ibis_check_version(guint required_major, guint required_minor,
                   guint required_micro)
{
	if(required_major > IBIS_MAJOR_VERSION) {
		return "ibis version too old (major mismatch)";
	}

#if IBIS_CHECK_VERSION(1, 0, 0)
	if(required_major < IBIS_MAJOR_VERSION) {
		return "ibis version too new (major mismatch)";
	}
#endif

	if(required_minor > IBIS_MINOR_VERSION) {
		return "ibis version too old (minor mismatch)";
	}

	if((required_minor == IBIS_MINOR_VERSION) &&
	   (required_micro > IBIS_MICRO_VERSION))
	{
		return "ibis version too old (micro mismatch)";
	}

	return NULL;
}
